@@ -48,7 +48,7 @@ import vobject
 
 if sys.version_info >= (3, 5):
     # HACK: Avoid import cycle for Python < 3.5
-    from . import xmlutils
+    from radicale import xmlutils
 
 if os.name == "nt":
     import ctypes
@@ -97,7 +97,7 @@ def load(configuration, logger):
     if sys.version_info < (3, 5):
         # HACK: Avoid import cycle for Python < 3.5
         global xmlutils
-        from . import xmlutils
+        from radicale import xmlutils
     storage_type = configuration.get("storage", "type")
     if storage_type == "multifilesystem":
         collection_class = Collection
@@ -138,7 +138,7 @@ def check_and_sanitize_item(vobject_item, is_collection=False, uid=None,
             if component_name is None or is_collection:
                 component_name = component.name
             elif component_name != component.name:
-                raise ValueError("Muliple component types in object: %r, %r" %
+                raise ValueError("Multiple component types in object: %r, %r" %
                                  (component_name, component.name))
             if component_name not in ("VTODO", "VEVENT", "VJOURNAL"):
                 continue
@@ -155,7 +155,7 @@ def check_and_sanitize_item(vobject_item, is_collection=False, uid=None,
                                  "object" % component_name)
             elif object_uid != component_uid:
                 raise ValueError(
-                    "Muliple %s components with different UIDs in object: "
+                    "Multiple %s components with different UIDs in object: "
                     "%r, %r" % (component_name, object_uid, component_uid))
             # vobject interprets recurrence rules on demand
             try:
@@ -779,7 +779,7 @@ class Collection(BaseCollection):
                                    (path, e)) from e
             tmp.close()
             os.replace(tmp.name, path)
-        except Exception:
+        except BaseException:
             tmp.close()
             os.remove(tmp.name)
             raise
@@ -1363,6 +1363,12 @@ class Collection(BaseCollection):
                 raw_text = f.read()
         except (FileNotFoundError, IsADirectoryError):
             return None, None
+        except PermissionError:
+            # Windows raises ``PermissionError`` when ``path`` is a directory
+            if (os.name == "nt" and
+                    os.path.isdir(path) and os.access(path, os.R_OK)):
+                return None, None
+            raise
         # The hash of the component in the file system. This is used to check,
         # if the entry in the cache is still valid.
         input_hash = self._item_cache_hash(raw_text)
