@@ -29,6 +29,7 @@ import copy
 import math
 import posixpath
 import re
+import sys
 import xml.etree.ElementTree as ET
 from collections import OrderedDict
 from datetime import date, datetime, timedelta, timezone
@@ -36,7 +37,7 @@ from http import client
 from itertools import chain
 from urllib.parse import quote, unquote, urlparse
 
-from . import storage
+from radicale import storage
 
 MIMETYPES = {
     "VADDRESSBOOK": "text/vcard",
@@ -647,7 +648,7 @@ def get_content_type(item):
 
 
 def find_tag(vobject_item):
-    """Find tag from ``vobject_item``."""
+    """Find component name from ``vobject_item``."""
     if vobject_item.name == "VCALENDAR":
         for component in vobject_item.components():
             if component.name != "VTIMEZONE":
@@ -656,7 +657,7 @@ def find_tag(vobject_item):
 
 
 def find_tag_and_time_range(vobject_item):
-    """Find tag and enclosing time range from ``vobject item``.
+    """Find component name and enclosing time range from ``vobject item``.
 
     Returns a tuple (``tag``, ``start``, ``end``) where ``tag`` is a string
     and ``start`` and ``end`` are POSIX timestamps (as int).
@@ -689,7 +690,13 @@ def find_tag_and_time_range(vobject_item):
         start = DATETIME_MIN
     if end is None:
         end = DATETIME_MAX
-    return tag, math.floor(start.timestamp()), math.ceil(end.timestamp())
+    try:
+        return tag, math.floor(start.timestamp()), math.ceil(end.timestamp())
+    except ValueError as e:
+        if str(e) == ("offset must be a timedelta representing a whole "
+                      "number of minutes") and sys.version_info < (3, 6):
+            raise RuntimeError("Unsupported in Python < 3.6: %s" % e) from e
+        raise
 
 
 def name_from_path(path, collection):
@@ -1138,8 +1145,18 @@ def report(base_prefix, path, xml_request, collection):
         # InfCloud asks for expand-property reports (even if we don't announce
         # support for them) and stops working if an error code is returned.
         logger.warning("Unsupported REPORT method %r on %r requested",
-                       root.tag, path)
+                       _tag_from_clark(root.tag), path)
         return client.MULTI_STATUS, multistatus
+    if (root.tag == _tag("C", "calendar-multiget") and
+            collection.get_meta("tag") != "VCALENDAR" or
+            root.tag == _tag("CR", "addressbook-multiget") and
+            collection.get_meta("tag") != "VADDRESSBOOK" or
+            root.tag == _tag("D", "sync-collection") and
+            collection.get_meta("tag") not in ("VADDRESSBOOK", "VCALENDAR")):
+        logger.warning("Invalid REPORT method %r on %r requested",
+                       _tag_from_clark(root.tag), path)
+        return (client.PRECONDITION_FAILED,
+                _webdav_error("D", "supported-report"))
     prop_element = root.find(_tag("D", "prop"))
     props = (
         [prop.tag for prop in prop_element]
